# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('rke')


class _ExportableConfig(types.ModuleType):
    @property
    def debug(self) -> bool:
        return __config__.get_bool('debug') or (_utilities.get_env_bool('RKE_DEBUG') or False)

    @property
    def log_file(self) -> Optional[str]:
        return __config__.get('logFile') or _utilities.get_env('RKE_LOG_FILE')

